@@ -18,6 +18,7 @@
 
 import subprocess
 import os
+import re
 import devedeng.configuration_data
 import devedeng.executor
 import devedeng.mux_dvd_menu
@@ -111,6 +112,25 @@ class ffmpeg(devedeng.executor.executor):
 
         devedeng.executor.executor.__init__(self)
         self.config = devedeng.configuration_data.configuration.get_config()
+        try:
+            version_number = 7
+            handle = subprocess.Popen(
+                ["ffmpeg", "-version"], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+            (stdout, stderr) = handle.communicate()
+            if 0 == handle.wait():
+                for line in stdout.decode("latin-1").split("\n"):
+                    line = line.strip()
+                    if line.startswith("ffmpeg version "):
+                        version_number = int(re.search(r"[0-9]+", line).group())
+                        break
+        except:
+            version_number = 7
+            pass
+        print(f"Detected ffmpeg version number: {version_number}")
+        if version_number <= 6:
+            self._filter_sep = ",fifo,"
+        else:
+            self._filter_sep = ","
 
 
     def convert_file(self, file_project, output_file, video_length, pass2=False):
@@ -180,25 +200,25 @@ class ffmpeg(devedeng.executor.executor):
 
             if (file_project.prerotation == 90):
                 if (cmd_line != ""):
-                    cmd_line += ",fifo,"
+                    cmd_line += self._filter_sep
                 cmd_line += "transpose=1"
             elif (file_project.prerotation == -90) or (file_project.prerotation == 270):
                 if (cmd_line != ""):
-                    cmd_line += ",fifo,"
+                    cmd_line += self._filter_sep
                 cmd_line += "transpose=2"
             elif (file_project.prerotation == 180):
                 if (cmd_line != ""):
-                    cmd_line += ",fifo,"
+                    cmd_line += self._filter_sep
                 vflip = not vflip
                 hflip = not hflip
 
             if (file_project.rotation == "rotation_90"):
                 if (cmd_line != ""):
-                    cmd_line += ",fifo,"
+                    cmd_line += self._filter_sep
                 cmd_line += "transpose=1"
             elif (file_project.rotation == "rotation_270"):
                 if (cmd_line != ""):
-                    cmd_line += ",fifo,"
+                    cmd_line += self._filter_sep
                 cmd_line += "transpose=2"
             elif (file_project.rotation == "rotation_180"):
                 vflip = not vflip
@@ -211,16 +231,16 @@ class ffmpeg(devedeng.executor.executor):
 
             if (vflip):
                 if (cmd_line != ""):
-                    cmd_line += ",fifo,"
+                    cmd_line += self._filter_sep
                 cmd_line += "vflip"
             if (hflip):
                 if (cmd_line != ""):
-                    cmd_line += ",fifo,"
+                    cmd_line += self._filter_sep
                 cmd_line += "hflip"
 
             if (file_project.width_midle != file_project.original_width) or (file_project.height_midle != file_project.original_height):
                 if (cmd_line != ""):
-                    cmd_line += ",fifo,"
+                    cmd_line += self._filter_sep
                 x = int((file_project.width_midle - file_project.original_width) / 2)
                 y = int((file_project.height_midle - file_project.original_height) / 2)
                 if (x > 0) or (y > 0):
@@ -230,7 +250,7 @@ class ffmpeg(devedeng.executor.executor):
 
             if (file_project.width_final != file_project.width_midle) or (file_project.height_final != file_project.height_midle):
                 if (cmd_line != ""):
-                    cmd_line += ",fifo,"
+                    cmd_line += self._filter_sep
                 cmd_line += "scale=" + \
                     str(file_project.width_final) + ":" + \
                     str(file_project.height_final)
